****
daul
****

**daul** is a package containing data analysis and other utilities for python. 

Compatibility
*************

Currently, only Python 2.7. 

Documentation
*************

You can find the documentation at `Read the Docs <https://daul.readthedocs.io/en/latest>`_.

Installation
************

Install the latest release using: 

``$ pip install daul``

License
*******

Licensed under MIT license.
